pub struct Pss<D> {
pub blinded: bool,
pub digest: D,
pub salt_len: Option<usize>,
}Expand description
Digital signatures using PSS padding.
Fields
blinded: boolCreate blinded signatures.
digest: DDigest type to use.
salt_len: Option<usize>Salt length. Required for signing, optional for verifying.
Implementations
Sourceimpl<D> Pss<D>where
D: Digest,
impl<D> Pss<D>where
D: Digest,
Sourcepub fn new() -> Self
pub fn new() -> Self
New PSS padding for the given digest. Digest output size is used as a salt length.
Sourcepub fn new_with_salt(len: usize) -> Self
pub fn new_with_salt(len: usize) -> Self
New PSS padding for the given digest with a salt value of the given length.
Sourcepub fn new_blinded() -> Self
pub fn new_blinded() -> Self
New PSS padding for blinded signatures (RSA-BSSA) for the given digest. Digest output size is used as a salt length.
Sourcepub fn new_blinded_with_salt(len: usize) -> Self
pub fn new_blinded_with_salt(len: usize) -> Self
New PSS padding for blinded signatures (RSA-BSSA) for the given digest with a salt value of the given length.