pub type Signature = GenericSignature<BoxedUint>;Available on crate feature
alloc only.Expand description
Boxed PSS signature alias used by the alloc code path.
Aliased Type
pub struct Signature { /* private fields */ }pub type Signature = GenericSignature<BoxedUint>;alloc only.Boxed PSS signature alias used by the alloc code path.
pub struct Signature { /* private fields */ }