Module modmath_support

Module modmath_support 

Available on crate feature modmath only.
Generic modmath backend adapters for fixed-width RSA public-key paths.

Structs

ModMathForm
A value held in Montgomery form modulo a ModMathParams modulus.
ModMathParams
ModMathValuealloc

Traits

ModMathInt

Functions

public_key_from_be_bytes
Construct a public key backed by the modmath adapter from big-endian modulus bytes and a public exponent.
rsa_public_op
Apply the raw RSA public operation to a fixed-width block.