Pss

Struct Pss 

pub struct Pss<D> {
    pub blinded: bool,
    pub digest: D,
    pub salt_len: Option<usize>,
}
Digital signatures using PSS padding.

Fields

blinded: bool

Create blinded signatures.

digest: D

Digest type to use.

salt_len: Option<usize>

Salt length. Required for signing, optional for verifying.

Implementations

Source

impl<D> Pss<D>
where D: Digest,

pub fn new() -> Self

New PSS padding for the given digest. Digest output size is used as a salt length.

pub fn new_with_salt(len: usize) -> Self

New PSS padding for the given digest with a salt value of the given length.

pub fn new_blinded() -> Self

New PSS padding for blinded signatures (RSA-BSSA) for the given digest. Digest output size is used as a salt length.

pub fn new_blinded_with_salt(len: usize) -> Self

New PSS padding for blinded signatures (RSA-BSSA) for the given digest with a salt value of the given length.