SigningKey

Struct SigningKey 

pub struct SigningKey<D>
where D: Digest,
{ /* private fields */ }
Available on crate feature private-key only.
Signing key for producing RSASSA-PSS signatures as described in RFC8017  8.1.

Implementations

Source

impl<D> SigningKey<D>
where D: Digest,

pub fn new(key: RsaPrivateKey) -> Self

Create a new RSASSA-PSS signing key. Digest output size is used as a salt length.

pub fn new_with_salt_len(key: RsaPrivateKey, salt_len: usize) -> Self

Create a new RSASSA-PSS signing key with a salt of the given length.

pub fn random<R: CryptoRng + ?Sized>( rng: &mut R, bit_size: usize, ) -> Result<Self>

Generate a new random RSASSA-PSS signing key. Digest output size is used as a salt length.

pub fn random_with_salt_len<R: CryptoRng + ?Sized>( rng: &mut R, bit_size: usize, salt_len: usize, ) -> Result<Self>

Generate a new random RSASSA-PSS signing key with a salt of the given length.

pub fn salt_len(&self) -> usize

Return specified salt length for this key