pub struct SigningKey<D>where
D: Digest,{ /* private fields */ }Available on crate feature
private-key only.Expand description
Signing key for producing RSASSA-PSS signatures as described in RFC8017  8.1.
Implementations
Sourceimpl<D> SigningKey<D>where
D: Digest,
impl<D> SigningKey<D>where
D: Digest,
Sourcepub fn new(key: RsaPrivateKey) -> Self
pub fn new(key: RsaPrivateKey) -> Self
Create a new RSASSA-PSS signing key. Digest output size is used as a salt length.
Sourcepub fn new_with_salt_len(key: RsaPrivateKey, salt_len: usize) -> Self
pub fn new_with_salt_len(key: RsaPrivateKey, salt_len: usize) -> Self
Create a new RSASSA-PSS signing key with a salt of the given length.
Sourcepub fn random<R: CryptoRng + ?Sized>(
rng: &mut R,
bit_size: usize,
) -> Result<Self>
pub fn random<R: CryptoRng + ?Sized>( rng: &mut R, bit_size: usize, ) -> Result<Self>
Generate a new random RSASSA-PSS signing key. Digest output size is used as a salt length.