pub struct GenericRsaPublicKey<T, M>where
T: UnsignedModularInt,
M: ModulusParams<Modulus = T>,{ /* private fields */ }Expand description
Represents the public part of an RSA key.
Implementations
Sourceimpl<T, M> GenericRsaPublicKey<T, M>where
T: UnsignedModularInt,
M: ModulusParams<Modulus = T>,
impl<T, M> GenericRsaPublicKey<T, M>where
T: UnsignedModularInt,
M: ModulusParams<Modulus = T>,
Sourcepub fn from_components(n: T, e: T, n_params: M) -> Result<Self>
pub fn from_components(n: T, e: T, n_params: M) -> Result<Self>
Create a public key from already-validated components and modulus parameters.
This is intended for alternate bigint backends that prepare their own
modular arithmetic context outside the BoxedUint constructors.
Sourceimpl<T, M> GenericRsaPublicKey<T, M>where
T: UnsignedModularInt,
M: ModulusParams<Modulus = T>,
impl<T, M> GenericRsaPublicKey<T, M>where
T: UnsignedModularInt,
M: ModulusParams<Modulus = T>,
Sourcepub fn encrypt<R: CryptoRng + ?Sized, P: PaddingScheme>(
&self,
rng: &mut R,
padding: P,
msg: &[u8],
) -> Result<Vec<u8>>
Available on crate feature alloc only.
pub fn encrypt<R: CryptoRng + ?Sized, P: PaddingScheme>( &self, rng: &mut R, padding: P, msg: &[u8], ) -> Result<Vec<u8>>
alloc only.Encrypt the given message.
Sourcepub fn verify<S: SignatureScheme>(
&self,
scheme: S,
hashed: &[u8],
sig: &[u8],
) -> Result<()>
pub fn verify<S: SignatureScheme>( &self, scheme: S, hashed: &[u8], sig: &[u8], ) -> Result<()>
Verify a signed message.
hashed must be the result of hashing the input using the hashing function
passed in through hash.
If the message is valid Ok(()) is returned, otherwise an Err indicating failure.
Sourceimpl GenericRsaPublicKey<BoxedUint, BoxedMontyParams>
impl GenericRsaPublicKey<BoxedUint, BoxedMontyParams>
Sourcepub const MIN_PUB_EXPONENT: u64 = 2
Available on crate feature alloc only.
pub const MIN_PUB_EXPONENT: u64 = 2
alloc only.Minimum value of the public exponent e.
Sourcepub const MAX_PUB_EXPONENT: u64
Available on crate feature alloc only.
pub const MAX_PUB_EXPONENT: u64
alloc only.Maximum value of the public exponent e.
Very large public exponents are a potential denial-of-service vector (a.k.a. “RSADoS”) because they increase the amount of work required for e.g. signature verification. See:
https://www.imperialviolet.org/2012/03/17/rsados.html
The particular constant below has been chosen to align with ring where this value was selected based on the history of this particular issue, API compatibility concerns, and benchmark-driven evaluation. See RustCrypto/RSA#155.
If for some reason you have a legitimate reason to use keys with public exponents larger than this value, use the special APIs:
- [
RsaPublicKey::new_with_large_exp] RsaPrivateKey::from_components_with_large_exponent
Sourcepub const MAX_SIZE: usize = 8192
Available on crate feature alloc only.
pub const MAX_SIZE: usize = 8192
alloc only.Maximum size of the modulus n in bits.
Sourcepub fn new(n: BoxedUint, e: BoxedUint) -> Result<Self>
Available on crate feature alloc only.
pub fn new(n: BoxedUint, e: BoxedUint) -> Result<Self>
alloc only.Create a new public key from its components.
This function accepts public keys with a modulus size up to 8192-bits,
i.e. RsaPublicKey::MAX_SIZE.
Sourcepub fn new_with_max_size(
n: BoxedUint,
e: BoxedUint,
max_size: usize,
) -> Result<Self>
Available on crate feature alloc only.
pub fn new_with_max_size( n: BoxedUint, e: BoxedUint, max_size: usize, ) -> Result<Self>
alloc only.Create a new public key from its components.
Sourcepub fn new_unchecked(n: BoxedUint, e: BoxedUint) -> Self
Available on crate feature alloc only.
pub fn new_unchecked(n: BoxedUint, e: BoxedUint) -> Self
alloc only.Create a new public key, bypassing checks around the modulus and public exponent size.
This method is not recommended, and only intended for unusual use cases.
Most applications should use RsaPublicKey::new or
RsaPublicKey::new_with_max_size instead.